Enumeration
QmiLocPositionSource
since: 1.37
Description [src]
Source from which this position was obtained. If altitude is specified and the altitude source is not specified, the engine assumes that the altitude was obtained using the specified position source. If both altitude and altitude source are specified, the engine assumes that only latitude and longitude were obtained using the specified position source.
Available since: 1.37
Members
-
QMI_LOC_POSITION_SOURCE_GNSS -
Position source is GNSS.
- Value:
0 - Available since: 1.37
- Value:
-
QMI_LOC_POSITION_SOURCE_CELL_ID -
Position is based on Cell ID.
- Value:
1 - Available since: 1.37
- Value:
-
QMI_LOC_POSITION_SOURCE_ENHANCED_CELL_ID -
Position is based on enhaced information about Cell ID.
- Value:
2 - Available since: 1.37
- Value:
-
QMI_LOC_POSITION_SOURCE_WIFI -
Position is based on available WiFi networks.
- Value:
3 - Available since: 1.37
- Value:
-
QMI_LOC_POSITION_SOURCE_TERRESTRIAL -
Position source is terrestrial.
- Value:
4 - Available since: 1.37
- Value:
-
QMI_LOC_POSITION_SOURCE_GNSS_TERRESTRIAL_HYBRID -
Position source is GNSS terrestrial hybrid.
- Value:
5 - Available since: 1.37
- Value:
-
QMI_LOC_POSITION_SOURCE_OTHER -
Other sources of position information.
- Value:
6 - Available since: 1.37
- Value:
-
QMI_LOC_POSITION_SOURCE_DRE -
Position source is the Dead Reckoning Engine.
- Value:
7 - Available since: 1.37
- Value:
-
QMI_LOC_POSITION_SOURCE_FLP -
Position source is Fused Location Provider.
- Value:
8 - Available since: 1.37
- Value:
-
QMI_LOC_POSITION_SOURCE_NLP -
Position source is Network Location Provider.
- Value:
9 - Available since: 1.37
- Value:
-
QMI_LOC_POSITION_SOURCE_FLP_ALE -
Position source is derived from Fused Location Provider - Android Location Engine.
- Value:
10 - Available since: 1.37
- Value:
Type functions
qmi_loc_position_source_get_string
Gets the nickname string for the QmiLocPositionSource specified at val.
since: 1.37